@@ -1,10 +1,4 @@
 import matplotlib.pyplot as plt
-import seaborn as sns
-
-metrics = {
-    "Train": [10.0, 9.0, 5.0, 2.0, 1.0],
-    "Validation": [12.0, 10.0, 7.0, 6.0, 3.0],
-}
 
 
 def line_plot(
@@ -18,6 +12,8 @@ def line_plot(
     palette="mako_r",
 ):
     """Produces a line plot based on a dictionary of metrics and labels."""
+    import seaborn as sns
+
     if show and path is not None:
         raise ValueError("Expected either `show` or `path` to be set, but not both.")
     if path is None and show is None:
@@ -25,7 +21,7 @@ def line_plot(
     palette = sns.color_palette("mako_r", len(data.keys()))
 
     sns.lineplot(data=data, palette=palette)
-    plt.legend(list(metrics.keys()))
+    plt.legend(list(data.keys()))
 
     if xlabel:
         plt.xlabel(xlabel)
@@ -48,6 +44,3 @@ def line_plot(
     elif show:
         plt.show()
         plt.close()
-
-
-line_plot(metrics, title="Loss")
